@@ -9,7 +9,7 @@ from warnings import warn
 try:
     import json
 except ImportError:
-    import simplejson as json
+    import simplejson as json  # NOQA
 
 
 from django.conf import settings
@@ -21,7 +21,7 @@ log = logging.getLogger(__name__)
 
 
 DEFAULT_HTTP_TIMEOUT = 5
-DEFAULT_VERIFICATION_URL = 'https://browserid.org/verify'
+DEFAULT_VERIFICATION_URL = 'https://verifier.login.persona.org/verify'
 OKAY_RESPONSE = 'okay'
 
 
@@ -36,17 +36,6 @@ def get_audience(request):
         SITE_URL = 'https://example.com'
         SITE_URL = 'http://example.com'
 
-    If you don't have a SITE_URL you can also use these varables:
-    PROTOCOL, DOMAIN, and (optionally) PORT.
-    Example 1:
-        PROTOCOL = 'https://'
-        DOMAIN = 'example.com'
-
-    Example 2:
-        PROTOCOL = 'http://'
-        DOMAIN = '127.0.0.1'
-        PORT = '8001'
-
     If none are set, we trust the request to populate the audience.
     This is *not secure*!
     """
@@ -59,32 +48,11 @@ def get_audience(request):
         req_proto = 'http://'
     req_domain = request.get_host()
 
-    # If we don't define it explicitly
-    if not site_url:
-        warn('Using DOMAIN and PROTOCOL to specify your BrowserID audience is '
-             'deprecated. Please use the SITE_URL setting instead.',
-             DeprecationWarning)
-
-        # DOMAIN is example.com req_domain is example.com:8001
-        domain = getattr(settings, 'DOMAIN', req_domain.split(':')[0])
-        protocol = getattr(settings, 'PROTOCOL', req_proto)
-
-        standards = {'https://': 443, 'http://': 80}
-        if ':' in req_domain:
-            req_port = req_domain.split(':')[1]
-        else:
-            req_port = None
-        port = getattr(settings, 'PORT', req_port or standards[protocol])
-        if port == standards[protocol]:
-            site_url = ''.join(map(str, (protocol, domain)))
-        else:
-            site_url = ''.join(map(str, (protocol, domain, ':', port)))
-
     req_url = "%s%s" % (req_proto, req_domain)
     if site_url != "%s%s" % (req_proto, req_domain):
-        log.warning('Misconfigured SITE_URL? settings has [%s], but '
-                    'actual request was [%s] BrowserID may fail on '
-                    'audience' % (site_url, req_url))
+        log.warning('Misconfigured SITE_URL? settings has {0}, but '
+                    'actual request was {1} BrowserID may fail on '
+                    'audience'.format(site_url, req_url))
     return site_url
 
 
@@ -94,10 +62,8 @@ def _verify_http_request(url, qs):
         'proxies': getattr(settings, 'BROWSERID_PROXY_INFO', None),
         'verify': not getattr(settings, 'BROWSERID_DISABLE_CERT_CHECK', False),
         'headers': {'Content-type': 'application/x-www-form-urlencoded'},
-        'params': {
-            'timeout': getattr(settings, 'BROWSERID_HTTP_TIMEOUT',
-                               DEFAULT_HTTP_TIMEOUT)
-        }
+        'timeout': getattr(settings, 'BROWSERID_HTTP_TIMEOUT',
+                           DEFAULT_HTTP_TIMEOUT),
     }
 
     if parameters['verify']:
@@ -108,8 +74,7 @@ def _verify_http_request(url, qs):
     try:
         rv = json.loads(r.content)
     except ValueError:
-        log.debug('Failed to decode JSON. Resp: %s, Content: %s' %
-                  (r.status_code, r.content))
+        log.debug('Failed to decode JSON. Resp: {0}, Content: {1}'.format(r.status_code, r.content))
         return dict(status='failure')
 
     return rv
@@ -120,7 +85,7 @@ def verify(assertion, audience):
     verify_url = getattr(settings, 'BROWSERID_VERIFICATION_URL',
                          DEFAULT_VERIFICATION_URL)
 
-    log.info("Verification URL: %s" % verify_url)
+    log.info("Verification URL: {0}".format(verify_url))
 
     result = _verify_http_request(verify_url, urllib.urlencode({
         'assertion': assertion,
@@ -130,7 +95,7 @@ def verify(assertion, audience):
     if result['status'] == OKAY_RESPONSE:
         return result
 
-    log.error('BrowserID verification failure. Response: %r '
-              'Audience: %r' % (result, audience))
-    log.error("BID assert: %r" % assertion)
+    log.error('BrowserID verification failure. Response: {0} '
+              'Audience: {1}'.format(result, audience))
+    log.error("BID assert: {0}".format(assertion))
     return False
