@@ -10,4 +10,4 @@ class BrowserIDForm(forms.Form):
     assertion = forms.CharField(widget=forms.HiddenInput())
 
     class Media:
-        js = ('browserid/browserid.js', 'https://browserid.org/include.js')
+        js = ('browserid/browserid.js', 'https://login.persona.org/include.js')
