@@ -36,12 +36,20 @@ class Verify(BaseFormView):
         """Handle a failed login. Use this to perform complex redirects
         post-login.
         """
-        return redirect(self.get_failure_url())
+        # Append "?bid_login_failed=1" to the URL to notify the JavaScript that
+        # login failed.
+        failure_url = self.get_failure_url()
+
+        if not failure_url.endswith('?'):
+            failure_url += '?' if not '?' in failure_url else '&'
+        failure_url += 'bid_login_failed=1'
+
+        return redirect(failure_url)
 
     def form_valid(self, form):
         """Handles the return post request from the browserID form and puts
         interesting variables into the class. If everything checks out, then
-        we call handle_user to decide how to handle a valid user
+        we call login_success to decide how to handle a valid user
         """
         self.assertion = form.cleaned_data['assertion']
         self.audience = get_audience(self.request)
@@ -58,7 +66,7 @@ class Verify(BaseFormView):
         return self.login_failure()
 
     def get(self, *args, **kwargs):
-        return redirect(self.get_failure_url())
+        return self.login_failure()
 
     def get_failure_url(self):
         """
